@@ -8,5 +8,4 @@ def gen_password(password_len, password_count):
             for x in range(0,password_len):
                 password_char = random.choice(chars)
                 password+=password_char
-            password+=f"\n\n\n{password}"
-        return password
+        return password+"\n\n"
